   /*=========================================================================
                                                                                
  Program:   crea
  Module:    $RCSfile: creaMessageManager.cxx,v $
  Language:  C++
  Date:      $Date: 2008/09/26 14:09:55 $
  Version:   $Revision: 1.1.1.1 $
                                                                                
  Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
  l'Image). All rights reserved. See Doc/License.txt or
  http://www.creatis.insa-lyon.fr/Public/Gdcm/License.html for details.
                                                                                
     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notices for more information.
                                                                                
=========================================================================*/
/**
 * \file
 * \brief class MessageManager : Manages the messages displayed by crea (code)
 */
#include "creaMessageManager.h"

namespace crea 
{

  MessageManager::MessageManager() 
    : mMaxMessageLength(8)//, mAllLevel(0), mMaxLevel(9)
    
  {
    std::string key;
    key ="all";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Minimum level for all kind of messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key ="max";
    mMessageLevel[key] = 9;
    mMessageHelp[key] = "Maximum level for all kind of messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "error";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Error messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "warning";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Warning messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "debug";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Debug messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "info";
    mMessageLevel[key] = 1;
    mMessageHelp[key] = "Information messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    /*
    key ="Kernel";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Messages generated by the core classes of the lib";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key ="process";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Messages related to box processing";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "Help";
    mMessageLevel[key] = 1;
    mMessageHelp[key] = "Help messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "Error";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Error messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "Warning";
    mMessageLevel[key] = 1;
    mMessageHelp[key] = "Warning messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "Output";
    mMessageLevel[key] = 1;
    mMessageHelp[key] = "Output messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "debug";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Debug messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "Config";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Configuration related messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "data";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Data related messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "wx";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Widgets related messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "gui";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Graphical user interface related messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "object";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "object memory related messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "package";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Packages related messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "connection";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Connections related messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    key = "modified";
    mMessageLevel[key] = 0;
    mMessageHelp[key] = "Modified related messages";
    if (mMaxMessageLength<key.length()) mMaxMessageLength = key.length();
    */
   }




  MessageManager::~MessageManager() 
  {
    //      std::cout << "~MessageManager"<<std::endl;
  }
  


  MessageManager* MessageManager::GetInstance() 
  { 
    static MessageManager* m = 0;
    if (!m) m = new MessageManager();
    return m; 
  }

  void MessageManager::RegisterMessageType(std::string key, 
						  std::string help,
						  unsigned char default_level) 
  {
    GetInstance()->mMessageLevel[key] = default_level;
    GetInstance()->mMessageHelp[key] = help;
    if (GetInstance()->mMaxMessageLength<key.length()) 
      GetInstance()->mMaxMessageLength = key.length();
  }



  void MessageManager::SetMessageLevel(std::string key, 
					      unsigned char level) 
  {
    std::map<std::string,int>::iterator i;
    i = GetInstance()->mMessageLevel.find(key);
    if (i!=GetInstance()->mMessageLevel.end()) 
      {
	(*i).second = level;
      }
    else 
      {
	creaWarning("MessageManager::SetMessageLevel : message type=<"
		    <<key<<"> unregistered");
      }
    
  }
  
  
  
  int MessageManager::GetMessageLevel(std::string key) 
  {
    int l = GetInstance()->mMessageLevel["all"];
    std::map<std::string,int>::iterator i = 
      GetInstance()->mMessageLevel.find(key);
    if (i!=GetInstance()->mMessageLevel.end()) {
      if ( (*i).second > l ) l = (*i).second;      
    }
    int m = GetInstance()->mMessageLevel["max"];
    if (l>m) l=m;
    return l;
  }



  void MessageManager::PrintInfo() 
  {
    creaMessage("info",1,"================ Messages =================" 
		<< creaendl);
    creaMessage("info",1, "Kind");
    for (int k=0;
	 k<(int)(GetInstance()->mMaxMessageLength-2);
	 k++) 
      {
	creaMessageCont("info",1," "); 
      }
    creaMessageCont("info",1,"Level  Nature" << creaendl);
    std::map<std::string,int>::iterator i;
    std::map<std::string,std::string>::iterator j;  
    for (i=GetInstance()->mMessageLevel.begin(),
	   j=GetInstance()->mMessageHelp.begin();
	 i!=GetInstance()->mMessageLevel.end();++i,++j) {
      creaMessage("info",1, (*i).first);
      for (int k=0;
	   k<(int)(GetInstance()->mMaxMessageLength+2-(*i).first.length());
	   k++) {
	creaMessageCont("info",1," ");
      }
      creaMessageCont("info",1, (*i).second << "\t" 
		      << (*j).second << creaendl);
    }
    creaMessage("info",1,"===========================================" 
		<< creaendl);
  }
  

}
